@@ -17,7 +17,7 @@ use Cwd;
 sub import {
     my $class = shift;
     if ($ENV{PERL5LIB}) {
-        $ENV{PERL5LIB} = $ENV{PERL5LIB}.":".getcwd()."/lib";
+        $ENV{PERL5LIB} = getcwd()."/lib:".$ENV{PERL5LIB};
     }
     else {
         $ENV{PERL5LIB} = getcwd()."/lib";
@@ -67,7 +67,7 @@ sub local_ubic {
         service_dirs => { type => ARRAYREF, default => ['t/service/common', 'etc/ubic/service'] },
         default_user => {
             type => SCALAR,
-            default => $ENV{LOGNAME} || $ENV{USERNAME},
+            default => $ENV{LOGNAME} || $ENV{USERNAME} || scalar getpwuid($>),
         },
     });
 
